# csp-discord

Alias for csp-adapter-discord

[![Build Status](https://github.com/timkpaine/csp-discord/actions/workflows/build.yml/badge.svg?branch=main&event=push)](https://github.com/timkpaine/csp-discord/actions/workflows/build.yml)
[![codecov](https://codecov.io/gh/timkpaine/csp-discord/branch/main/graph/badge.svg)](https://codecov.io/gh/timkpaine/csp-discord)
[![License](https://img.shields.io/github/license/timkpaine/csp-discord)](https://github.com/timkpaine/csp-discord)
[![PyPI](https://img.shields.io/pypi/v/csp-discord.svg)](https://pypi.python.org/pypi/csp-discord)

## Overview


> [!NOTE]
> This library was generated using [copier](https://copier.readthedocs.io/en/stable/) from the [Base Python Project Template repository](https://github.com/python-project-templates/base).
